package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsKnowledgeLube;

/**
 * 润滑知识库Service接口
 * 
 * @author caoql
 * @date 2024-02-26
 */
public interface IDmsKnowledgeLubeService 
{
    /**
     * 查询润滑知识库
     * 
     * @param knowledgeLubeId 润滑知识库主键
     * @return 润滑知识库
     */
    public DmsKnowledgeLube selectDmsKnowledgeLubeByKnowledgeLubeId(Long knowledgeLubeId);

    /**
     * 查询润滑知识库列表
     * 
     * @param dmsKnowledgeLube 润滑知识库
     * @return 润滑知识库集合
     */
    public List<DmsKnowledgeLube> selectDmsKnowledgeLubeList(DmsKnowledgeLube dmsKnowledgeLube);

    /**
     * 新增润滑知识库
     * 
     * @param dmsKnowledgeLube 润滑知识库
     * @return 结果
     */
    public int insertDmsKnowledgeLube(DmsKnowledgeLube dmsKnowledgeLube);

    /**
     * 修改润滑知识库
     * 
     * @param dmsKnowledgeLube 润滑知识库
     * @return 结果
     */
    public int updateDmsKnowledgeLube(DmsKnowledgeLube dmsKnowledgeLube);

    /**
     * 批量删除润滑知识库
     * 
     * @param knowledgeLubeIds 需要删除的润滑知识库主键集合
     * @return 结果
     */
    public int deleteDmsKnowledgeLubeByKnowledgeLubeIds(Long[] knowledgeLubeIds);

    /**
     * 删除润滑知识库信息
     * 
     * @param knowledgeLubeId 润滑知识库主键
     * @return 结果
     */
    public int deleteDmsKnowledgeLubeByKnowledgeLubeId(Long knowledgeLubeId);
}
